SoftplusLoss
============

.. currentmodule:: pykeen.losses

.. autoclass:: SoftplusLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SoftplusLoss.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
